CITY_OWNED_EXCLUSION_FILTERS = {
    "owner_1": [
        "CITY OF PHILA",
        "PHILA HOUSING AUTHORITY",
        "CITY OF PHILADELPHIA",
        "PHILADELPHIA HOUSING",
        "REDEVELOPMENT AUTHORITY",
        "REDEVELOPMENT AUTHORITY O",
        "SCHOOL DISTRICT OF PHILA",
        "PHILADELPHIA HOUSING AUTH",
        "PHILA HOUSING AUTHORITY",
        "PHILADELPHIA LAND BANK",
        "PHILADELPHIA HOUSING DEVE",
        "CITY OC PHILA",
        "CITY HALL ANNEX",
    ],
    "mailing_street": [
        "12 S 23RD ST",
        "1401 JOHN F KENNEDY BLVD",
        "790 CITY HALL",
        "CITY HALL ANNEX",
        "CITY HALL RM 784",
        "CITY HALL",
        "723 CITY HALL ANNEX",
        "3100 PENROSE FERRY RD",
    ],
}




class SearchTypeNotImplementedError(Exception):
    """Exception raised for errors where search type provided isn't implemented."""

    def __init__(self, search_type): 
        self.message = (
            f"Invalid search_type: '{search_type}' provided. Must be one of: ('owner', "
            "'mailing_address', 'location_by_mailing_address', 'location_by_owner')"
        )
        super().__init__(self.message)


class SearchMethodNotImplementedError(Exception):
    """Exception raised for errors where search method provided isn't implemented."""

    def __init__(self, search_method): 
        self.message = (
            f"Invalid search_method: '{search_method}' provided. Must be one of: "
            "('contains', 'starts_with', 'ends_with')"
        )
        super().__init__(self.message)
